import os
import configparser

class TurbineConfiguration:
    def __init__(self) -> None:
        config_dir = os.path.join(os.path.expanduser("~"), ".turbineml")
        if not os.path.exists(config_dir):
            os.makedirs(config_dir)

        self.config_path = os.path.join(config_dir, "config")
        self._read_config()
    
    def _read_config(self):
        self.config = configparser.ConfigParser()
        if os.path.exists(self.config_path):
            self.config.read(self.config_path)
        if not "turbineml" in self.config:
            self.config.add_section("turbineml")
    
    def _write_config(self):
        with open(self.config_path, "w") as configfile:
            self.config.write(configfile)

    def get_api_key(self):
        if "TURBINE_API_KEY" in os.environ:
            return os.environ["TURBINE_API_KEY"]
        return self.config.get("turbineml", "api_key", fallback=None)
    
    def set_api_key(self, api_key):
        self._read_config()
        self.config.set("turbineml", "api_key", api_key)
        self._write_config()
    
    def get_api_url(self):
        if "TURBINE_API_ENDPOINT" in os.environ:
            return os.environ["TURBINE_API_ENDPOINT"]
        return "https://app.turbineml.com/api/"

_config = TurbineConfiguration()



import os

class FileWrapper:
    def __init__(self, fd, callback) -> None:
        self.fd = fd
        self.callback = callback
        self.length = os.fstat(fd.fileno()).st_size
    
    def __len__(self):
        return self.length
    
    def read(self, length=-1):
        result = self.fd.read(length)
        self.callback(len(result))
        return result


import os

def _get_cache_dir():
    return os.path.join(os.path.expanduser("~"), ".turbineml", "volume_cache")

def init_cache():
    cache_dir = _get_cache_dir()
    if not os.path.exists(cache_dir):
        os.makedirs(cache_dir)

def file_exists(digest):
    return os.path.exists(get_path(digest))

def get_path(digest):
    return os.path.join(_get_cache_dir(), digest)



import os.path
import setuptools

current_dir = os.path.dirname(__file__)

with open(os.path.join(current_dir, "README.md"), "r", encoding="utf-8") as f:
    long_description = f.read()

with open(os.path.join(current_dir, "turbineml/version.py"), "r", encoding="utf-8") as f:
    version_file = f.read()

version = None
for line in version_file.splitlines():
    if line.startswith('__version__'):
        delim = '"' if '"' in line else "'"
        version = line.split(delim)[1]
if version is None:
    raise RuntimeError("Version not found")

with open(os.path.join(current_dir, "requirements.txt"), "r", encoding="utf-8") as f:
    requirements = f.read().splitlines()


setuptools.setup(
    name="turbineml",
    version=version,
    author="Turbine ML",
    author_email="info@turbineml.com",
    description="Turbine ML",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/turbineml/turbine-client",
    project_urls={
        "Bug Tracker": "https://github.com/turbineml/turbine-client/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(exclude=[]),
    install_requires=requirements,
    python_requires=">=3.6",
    entry_points={
        'console_scripts': [
            'turbine = turbineml.cli.main:main'
        ],
    },
)